systemtools.RedirectedStreams
=============================

.. abjad-lineage:: abjad.tools.systemtools.RedirectedStreams.RedirectedStreams

.. autoclass:: abjad.tools.systemtools.RedirectedStreams.RedirectedStreams

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.systemtools.RedirectedStreams.RedirectedStreams.stderr
      ~abjad.tools.systemtools.RedirectedStreams.RedirectedStreams.stdout
      ~abjad.tools.systemtools.RedirectedStreams.RedirectedStreams.__enter__
      ~abjad.tools.systemtools.RedirectedStreams.RedirectedStreams.__eq__
      ~abjad.tools.systemtools.RedirectedStreams.RedirectedStreams.__exit__
      ~abjad.tools.systemtools.RedirectedStreams.RedirectedStreams.__format__
      ~abjad.tools.systemtools.RedirectedStreams.RedirectedStreams.__hash__
      ~abjad.tools.systemtools.RedirectedStreams.RedirectedStreams.__ne__
      ~abjad.tools.systemtools.RedirectedStreams.RedirectedStreams.__repr__

Bases
-----

- :py:class:`abctools.ContextManager <abjad.tools.abctools.ContextManager.ContextManager>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.systemtools.RedirectedStreams.RedirectedStreams.stderr
   :noindex:

.. autoattribute:: abjad.tools.systemtools.RedirectedStreams.RedirectedStreams.stdout
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.systemtools.RedirectedStreams.RedirectedStreams.__enter__
   :noindex:

.. automethod:: abjad.tools.systemtools.RedirectedStreams.RedirectedStreams.__eq__
   :noindex:

.. automethod:: abjad.tools.systemtools.RedirectedStreams.RedirectedStreams.__exit__
   :noindex:

.. automethod:: abjad.tools.systemtools.RedirectedStreams.RedirectedStreams.__format__
   :noindex:

.. automethod:: abjad.tools.systemtools.RedirectedStreams.RedirectedStreams.__hash__
   :noindex:

.. automethod:: abjad.tools.systemtools.RedirectedStreams.RedirectedStreams.__ne__
   :noindex:

.. automethod:: abjad.tools.systemtools.RedirectedStreams.RedirectedStreams.__repr__
   :noindex:
